#!/bin/bash
WHOAMI=root
VERSION=0.9a

INSTALL_PATH=/usr
DEFAULT_INCDIR="$INSTALL_PATH"/include
DEFAULT_MANDIR="$INSTALL_PATH"/man
DEFAULT_LIBDIR="$INSTALL_PATH"/lib

if [ `whoami` != "$WHOAMI" ]
then
   echo
   echo "  Sorry, you must have root privileges to execute this script"
   echo
   exit 1
fi
echo
echo
echo    "  This script installs PCthreads in the system-wide directories"
echo    "  to make the facility available to all users.  The default"
echo    "  directories assumed by this script are:"
echo    ""
echo    "       "$INSTALL_PATH"/include and "$INSTALL_PATH"/include/dce"
echo    "       "$INSTALL_PATH"/lib"
echo    "       "$INSTALL_PATH"/man3"
echo    ""
echo    ""
echo -n "  Please specify the installation directory ("$INSTALL_PATH"): "
read install_dir

if [ "$install_dir" = "" ]
then
    install_dir="$INSTALL_PATH"
else
    if [ "$install_dir" != "$INSTALL_PATH" ]
    then
        INSTALL_PATH="$install_dir"/pthreads-$VERSION
    fi
fi

DEST_INCDIR=$INSTALL_PATH/include
DEST_LIBDIR=$INSTALL_PATH/lib
DEST_MANDIR=$INSTALL_PATH/man

echo
echo   "  You've selected "$INSTALL_PATH". The PCthread facilities will be"
echo   "  installed in the following directories:"
echo
echo   "        "$DEST_INCDIR" and "$DEST_INCDIR"/dce"
echo   "        "$DEST_LIBDIR""
echo   "        "$DEST_MANDIR"/man3"
echo
echo   "  If these directories are not present, they will be created."
echo   "  Also, if you've selected an installation directory other"
echo   "  than /usr, you'll have to set the -L and -I flags so that"
echo   "  your pager (e.g., man) and your build environment can find"
echo   "  these files."
echo
echo -n " Continue (N): "
read confirm

if [ "$confirm" != "Y" ]
then
    if [ "$confirm" != "y" ]
    then
        echo
        echo "  *** Installation aborted! ***"
        echo
        exit 1
    fi
fi

set -x

OLDINCS="$DEST_INCDIR/pthrea* $DEST_INCDIR/dce/pthread.h $DEST_INCDIR/dce/exc_handling.h $DEST_INCDIR/dce/pthread_exc.h $DEST_INCDIR/typedefs.h"
OLDLIBS="$DEST_LIBDIR/libpthrea*"
OLDPAGES="$DEST_MANDIR/man3/pthread_* $DEST_MANDIR/man3/sigwait*"

if [ ! -d $INSTALL_PATH ]
then
   mkdir $INSTALL_PATH
fi

########################################################################
#  If directories need to be made, make them.  Otherwise, remove any   #
#  files from a preexisting installation.                              #
########################################################################
if [ ! -d $DEST_INCDIR ]
then
   mkdir $DEST_INCDIR
fi

if [ ! -d $DEST_INCDIR/dce ]
then
   mkdir $DEST_INCDIR/dce   
else
   rm -f $OLDINCS
fi

if [ ! -d $DEST_LIBDIR ]
then
   mkdir $DEST_LIBDIR
else
   rm -f $OLDLIBS
fi

if [ ! -d $DEST_MANDIR ]
then
   mkdir $DEST_MANDIR
fi

if [ ! -d $DEST_MANDIR/man3 ]
then
   mkdir $DEST_MANDIR/man3
else
   rm -f $OLDPAGES
fi

#
#   --  Install the libraries and header files
#
SOURCE_LIBDIR=./lib
SOURCE_INCDIR=./include
SOURCE_MANDIR=./man/man3

cp $SOURCE_LIBDIR/libpthr*.a $DEST_LIBDIR

cp $SOURCE_INCDIR/pthread_dce.h $DEST_INCDIR
cp $SOURCE_INCDIR/typedefs.h $DEST_INCDIR

cp $SOURCE_INCDIR/dce/pthread.h $DEST_INCDIR/dce
cp $SOURCE_INCDIR/dce/pthread_exc.h $DEST_INCDIR/dce
cp $SOURCE_INCDIR/dce/exc_handling.h $DEST_INCDIR/dce
ln -s $DEST_INCDIR/dce/pthread.h $DEST_INCDIR

#
# This block of commands copyies the manpages into the destination directory
# and then sets the appropriate symbolic links.
cp $SOURCE_MANDIR/*.gz $DEST_MANDIR/man3

ln -s $DEST_MANDIR/man3/pthread_mutex_lock.3.gz $DEST_MANDIR/man3/pthread_mutex_unlock.3.gz
ln -s $DEST_MANDIR/man3/pthread_mutex_init.3.gz $DEST_MANDIR/man3/pthread_mutex_destroy.3.gz
ln -s $DEST_MANDIR/man3/pthread_lock_global_np.3.gz $DEST_MANDIR/man3/pthread_unlock_global_np.3.gz
ln -s $DEST_MANDIR/man3/pthread_attr_init.3.gz $DEST_MANDIR/man3/pthread_attr_destroy.3.gz
ln -s $DEST_MANDIR/man3/pthread_mutexattr_init.3.gz $DEST_MANDIR/man3/pthread_mutexattr_destroy.3.gz
ln -s $DEST_MANDIR/man3/pthread_condattr_init.3.gz $DEST_MANDIR/man3/pthread_condattr_destroy.3.gz
ln -s $DEST_MANDIR/man3/pthread_cond_init.3.gz $DEST_MANDIR/man3/pthread_cond_destroy.3.gz
ln -s $DEST_MANDIR/man3/pthread_cond_signal.3.gz $DEST_MANDIR/man3/pthread_cond_broadcast.3.gz
ln -s $DEST_MANDIR/man3/pthread_key_create.3.gz $DEST_MANDIR/man3/pthread_key_delete.3.gz
ln -s $DEST_MANDIR/man3/pthread_key_getspecific.3.gz $DEST_MANDIR/man3/pthread_setspecific.3.gz

echo "Installation complete!"
